Struct Receiver
Source pub struct Receiver<T> {
inner: Arc<ChannelInner<T>>,
}
Available on crate feature full only.
The receiving end of a channel
Pushes a new item into the back of the channel
Pops the front item from the channel, blocking until an item is available
Pops the front item in the channel, if one exists
Creates a new Sender for this Receiver
The number of items available to pop from the channel
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.